@@ -10,6 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import collections
+
 from openstack.baremetal.v1 import _common
 from openstack import exceptions
 from openstack import resource
@@ -30,6 +32,23 @@ class ValidationResult(object):
         self.reason = reason
 
 
+class WaitResult(collections.namedtuple('WaitResult',
+                                        ['success', 'failure', 'timeout'])):
+    """A named tuple representing a result of waiting for several nodes.
+
+    Each component is a list of :class:`~openstack.baremetal.v1.node.Node`
+    objects:
+
+    :ivar ~.success: a list of :class:`~openstack.baremetal.v1.node.Node`
+        objects that reached the state.
+    :ivar ~.timeout: a list of :class:`~openstack.baremetal.v1.node.Node`
+        objects that reached timeout.
+    :ivar ~.failure: a list of :class:`~openstack.baremetal.v1.node.Node`
+        objects that hit a failure.
+    """
+    __slots__ = ()
+
+
 class Node(_common.ListMixin, resource.Resource):
 
     resources_key = 'nodes'
@@ -346,11 +365,11 @@ class Node(_common.ListMixin, resource.Resource):
         if config_drive:
             # Some config drive actions require a higher version.
             if isinstance(config_drive, dict):
-                version = '1.56'
+                version = _common.CONFIG_DRIVE_DICT_VERSION
             elif target == 'rebuild':
-                version = '1.35'
+                version = _common.CONFIG_DRIVE_REBUILD_VERSION
 
-        version = utils.pick_microversion(session, version)
+        version = self._assert_microversion_for(session, 'commit', version)
 
         body = {'target': target}
         if config_drive:
@@ -532,7 +551,7 @@ class Node(_common.ListMixin, resource.Resource):
         else:
             version = None
 
-        version = utils.pick_microversion(session, version)
+        version = self._assert_microversion_for(session, 'commit', version)
 
         # TODO(dtantsur): server timeout support
         body = {'target': target}
@@ -854,7 +873,8 @@ class Node(_common.ListMixin, resource.Resource):
                 raise exceptions.MethodNotSupported(self, "patch")
 
             session = self._get_session(session)
-            microversion = utils.pick_microversion(session, '1.45')
+            microversion = self._assert_microversion_for(
+                session, 'commit', _common.RESET_INTERFACES_VERSION)
             params = [('reset_interfaces', reset_interfaces)]
 
             request = self._prepare_request(requires_id=True,
