@@ -177,7 +177,9 @@ Additional information about the services can be found in the
 :ref:`service-proxies` documentation.
 """
 import warnings
+import weakref
 
+import futurist
 import keystoneauth1.exceptions
 import requestsexceptions
 import six
@@ -185,6 +187,7 @@ import six
 from openstack import _log
 from openstack import _services_mixin
 from openstack.cloud import openstackcloud as _cloud
+from openstack.cloud import _accelerator
 from openstack.cloud import _baremetal
 from openstack.cloud import _block_storage
 from openstack.cloud import _compute
@@ -248,6 +251,7 @@ def from_config(cloud=None, config=None, options=None, **kwargs):
 class Connection(
     _services_mixin.ServicesMixin,
     _cloud._OpenStackCloudMixin,
+    _accelerator.AcceleratorCloudMixin,
     _baremetal.BaremetalCloudMixin,
     _block_storage.BlockStorageCloudMixin,
     _compute.ComputeCloudMixin,
@@ -275,6 +279,7 @@ class Connection(
                  service_types=None,
                  global_request_id=None,
                  strict_proxies=False,
+                 pool_executor=None,
                  **kwargs):
         """Create a connection to a cloud.
 
@@ -342,6 +347,11 @@ class Connection(
             where it can be expected that the deployer config is correct and
             errors should be reported immediately.
             Default false.
+        :param pool_executor:
+        :type pool_executor: :class:`~futurist.Executor`
+            A futurist ``Executor`` object to be used for concurrent background
+            activities. Defaults to None in which case a ThreadPoolExecutor
+            will be created if needed.
         :param kwargs: If a config is not provided, the rest of the parameters
             provided are assumed to be arguments to be passed to the
             CloudRegion constructor.
@@ -377,13 +387,14 @@ class Connection(
 
         self._session = None
         self._proxies = {}
-        self.__pool_executor = None
+        self.__pool_executor = pool_executor
         self._global_request_id = global_request_id
         self.use_direct_get = use_direct_get
         self.strict_mode = strict
         # Call the _*CloudMixin constructors while we work on
         # integrating things better.
         _cloud._OpenStackCloudMixin.__init__(self)
+        _accelerator.AcceleratorCloudMixin.__init__(self)
         _baremetal.BaremetalCloudMixin.__init__(self)
         _block_storage.BlockStorageCloudMixin.__init__(self)
         _clustering.ClusteringCloudMixin.__init__(self)
@@ -432,7 +443,7 @@ class Connection(
             # Hide a reference to the connection on the session to help with
             # backwards compatibility for folks trying to just pass
             # conn.session to a Resource method's session argument.
-            self.session._sdk_connection = self
+            self.session._sdk_connection = weakref.proxy(self)
         return self._session
 
     def add_service(self, service):
@@ -469,7 +480,7 @@ class Connection(
                 attr_name.replace('-', '_'),
                 property(fget=getter)
             )
-            self.config.enable_service(attr_name)
+        self.config.enable_service(service.service_type)
 
     def authorize(self):
         """Authorize this Connection
@@ -490,6 +501,13 @@ class Connection(
         except keystoneauth1.exceptions.ClientException as e:
             raise exceptions.raise_from_response(e.response)
 
+    @property
+    def _pool_executor(self):
+        if not self.__pool_executor:
+            self.__pool_executor = futurist.ThreadPoolExecutor(
+                max_workers=5)
+        return self.__pool_executor
+
     def close(self):
         """Release any resources held open."""
         if self.__pool_executor:
